/*
** Module   : RowidExpression.java
** Abstract : Resolvable interface adapter for a rowid runtime expression
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------Description-----------------
** 001 CS  20130226 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * A convenience adapter class for a {@link Resolvable} runtime expression
 * which must return a {@link rowid} result.  Subclasses need implement
 * only the {@link #execute} method.
 */
public abstract class RowidExpression
implements Resolvable
{
   /**
    * Execute the underlying expression and get its result.
    *
    * @return  Result of expression execution.
    */
   public final BaseDataType resolve()
   {
      return execute();
   }
   
   /**
    * Report the return type expected from executing the expression.
    *
    * @return  Class indicating the type which will be returned by the
    *          expression.  Must be a variant of {@link BaseDataType}.
    */
   public final Class getType()
   {
      return rowid.class;
   }
   
   /**
    * Execute the underlying expression and get its result.
    *
    * @return  Result of expression execution as an <code>rowid</code>.
    */
   public abstract rowid execute();
}